0.7.0 (2019-08-27)
------------------

- Drop legacy update requirements method.


0.6.0 (2019-07-04)
------------------

- Display logs when a job fails.


0.5.1 (2019-04-16)
------------------

- Fix YAMLLoadWarning: https://msg.pyyaml.org/load


0.5.0 (2019-03-15)
------------------

- Add rabbitmq as a requirement.


0.4.0 (2019-03-06)
------------------

- Add generic method for `update-requirements` command.
- Improve django template.
- Remove git dependency.
- Drop support for legacy pip (`--before3.6.0-5` in update requirements command).


0.3.0 (2019-03-04)
------------------

- Fix support for CronJobs.
- Use newest version of minikube.
- Add support for uploading static files to S3.
- Add docker_args option to build command.
- Add optional NAME argument to variables command.

0.2.3 (2018-12-18)
------------------

- Fix README Markdown rendering on pypi.


0.2.2 (2018-12-18)
------------------

- Various fixes for Django template.


0.2.1 (2018-12-17)
------------------

- Add template for a Django project.


0.2.0 (2018-12-16)
------------------

- Initial public release.
